Bootstrap module for initial tenant setup and certificate management
Structs
- Create
Complete Tenant Options - Options for creating a complete tenant with all necessary setup
Functions
- bootstrap
- Bootstrap function that runs on application startup
- create_
complete_ tenant - Create a complete tenant with all necessary setup